pycocoa.basics

Package pycocoa :: Module basics |
[frames] | no frames]

# Module basics

Classes Adict, frozendict, decorator Proxy1ce and private (INTERNAL) functions and singletons.

Version: 25.06.09

Classes
| Adict A `dict` with key and attribute access to the items and callable to add items.
| frozendict An immutable Python `dict` with key and attribute access to the items.
| Proxy1ce Decorator for a lazily evaluated dict or lazily imported module or singleton, avoiding circular imports and providing access to the dict's items or the singleton's or module's attributes.

Functions
lambda1(arg) Inlieu of lambda arg: arg. |